# Bionty

Mapping and standardizing biological entities.

## Installation and configuration

Install the development version:
```
flit install -s --deps develop
```

## Quick start

- https://github.com/lamindev/bionty/blob/main/docs/guides/quickstart.ipynb
